==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/FinancialChartDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialChartCustomIndicatorArgsDescriptionMetadata } from "./FinancialChartCustomIndicatorArgsDescriptionMetadata";
import { XYChartDescriptionMetadata } from "./XYChartDescriptionMetadata";
import { FinancialChartDescription } from "./FinancialChartDescription";
/**
 * @hidden
 */
export let FinancialChartDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialChartDescriptionMetadata extends Base {
        static e(a) {
            a.item("TooltipTemplateRef", "(w:ToolTip)DataRef:String");
            a.item("_qualifiedName", "String:Infragistics.Controls.Charts.XamFinancialChart");
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
            a.item("Background", "(wf:BackColor/ColorTransform)Brush");
        }
        static b(a) {
            if (FinancialChartDescriptionMetadata.a == null) {
                FinancialChartDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialChartDescriptionMetadata.c(FinancialChartDescriptionMetadata.a);
            }
            if (a.k(FinancialChartDescriptionMetadata.a)) {
                return;
            }
            a.ab(FinancialChartDescriptionMetadata.a);
            FinancialChartCustomIndicatorArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            XYChartDescriptionMetadata.c(a);
            a.item("LeftMargin", "Number:double");
            a.item("IsHorizontalZoomEnabled", "Boolean");
            a.item("ToolbarHeight", "Number:double");
            a.item("YAxisIsLogarithmic", "Boolean");
            a.item("YAxisLogarithmBase", "Number:int");
            a.item("YAxisInterval", "Number:double");
            a.item("YAxisMinimumValue", "Number:double");
            a.item("YAxisMaximumValue", "Number:double");
            a.item("YAxisMinorInterval", "Number:double");
            a.item("VolumeType", "ExportedType:string:FinancialChartVolumeType");
            a.item("VolumeType@names", "None;Column;Line;Area");
            a.item("XAxisMode", "ExportedType:string:FinancialChartXAxisMode");
            a.item("XAxisMode@names", "Ordinal;Time");
            a.item("XAxisZoomMaximumCategoryRange", "Number:double");
            a.item("XAxisZoomToCategoryStart", "Number:double");
            a.item("XAxisZoomMaximumItemSpan", "Number:double");
            a.item("XAxisZoomToCategoryRange", "Number:double");
            a.item("XAxisZoomToItemSpan", "Number:double");
            a.item("YAxisMode", "ExportedType:string:FinancialChartYAxisMode");
            a.item("YAxisMode@names", "Numeric;PercentChange");
            a.item("IsToolbarVisible", "Boolean");
            a.item("ChartType", "ExportedType:string:FinancialChartType");
            a.item("ChartType@names", "Auto;Bar;Candle;Column;Line");
            a.item("YAxisLabelHorizontalAlignment", "ExportedType:string:HorizontalAlignment");
            a.item("YAxisLabelHorizontalAlignment@names", "Left;Center;Right;Stretch");
            a.item("IsWindowSyncedToVisibleRange", "Boolean");
            a.item("IndicatorTypes", "Collection:string:FinancialIndicatorTypeCollection:FinancialIndicatorType");
            a.item("IndicatorTypes@names", "AbsoluteVolumeOscillator;AccumulationDistribution;AverageDirectionalIndex;AverageTrueRange;BollingerBandWidth;ChaikinOscillator;ChaikinVolatility;CommodityChannelIndex;DetrendedPriceOscillator;EaseOfMovement;FastStochasticOscillator;ForceIndex;FullStochasticOscillator;MarketFacilitationIndex;MassIndex;MedianPrice;MoneyFlowIndex;MovingAverageConvergenceDivergence;NegativeVolumeIndex;OnBalanceVolume;PercentagePriceOscillator;PercentageVolumeOscillator;PositiveVolumeIndex;PriceVolumeTrend;RateOfChangeAndMomentum;RelativeStrengthIndex;SlowStochasticOscillator;StandardDeviation;StochRSI;TRIX;TypicalPrice;UltimateOscillator;WeightedClose;WilliamsPercentR");
            a.item("OverlayTypes", "Collection:string:FinancialOverlayTypeCollection:FinancialOverlayType");
            a.item("OverlayTypes@names", "BollingerBands;PriceChannel");
            a.item("YAxisAbbreviateLargeNumbers", "Boolean");
            a.item("Resolution", "Number:double");
            a.item("XAxisEnhancedIntervalPreferMoreCategoryLabels", "Boolean");
            a.item("YAxisEnhancedIntervalPreferMoreCategoryLabels", "Boolean");
            a.item("ZoomSliderType", "ExportedType:string:FinancialChartZoomSliderType");
            a.item("ZoomSliderType@names", "None;Auto;Bar;Candle;Column;Line;Area");
            a.item("NegativeBrushes", "BrushCollection:string");
            a.item("NegativeOutlines", "BrushCollection:string");
            a.item("OverlayBrushes", "BrushCollection:string");
            a.item("OverlayOutlines", "BrushCollection:string");
            a.item("VolumeOutlines", "BrushCollection:string");
            a.item("VolumeBrushes", "BrushCollection:string");
            a.item("IndicatorNegativeBrushes", "BrushCollection:string");
            a.item("IndicatorBrushes", "BrushCollection:string");
            a.item("VolumeThickness", "Number:double");
            a.item("OverlayThickness", "Number:double");
            a.item("OverlayMultiplier", "Number:double");
            a.item("IndicatorThickness", "Number:double");
            a.item("IndicatorDisplayTypes", "Collection:string:IndicatorDisplayTypeCollection:IndicatorDisplayType");
            a.item("IndicatorDisplayTypes@names", "Line;Area;Column");
            a.item("IndicatorPeriod", "Number:int");
            a.item("IndicatorMultiplier", "Number:double");
            a.item("IndicatorSmoothingPeriod", "Number:int");
            a.item("IndicatorShortPeriod", "Number:int");
            a.item("IndicatorLongPeriod", "Number:int");
            a.item("IndicatorSignalPeriod", "Number:int");
            a.item("RangeSelectorOptions", "Collection:string:FinancialChartRangeSelectorOptionCollection:FinancialChartRangeSelectorOption");
            a.item("RangeSelectorOptions@names", "OneMonth;ThreeMonths;SixMonths;YearToDate;OneYear;All");
            a.item("CustomIndicatorNames", "Collection:String:CustomIndicatorNameCollection:String");
            a.item("IsVerticalZoomEnabled", "Boolean");
            a.item("ZoomSliderXAxisMajorStroke", "Brush");
            a.item("ZoomSliderXAxisMajorStrokeThickness", "Number:double");
            a.item("IsLegendVisible", "Boolean");
            a.item("XAxisMinimumValue", "Date");
            a.item("XAxisMaximumValue", "Date");
            a.item("XAxisBreaks", "Collection:TimeAxisBreak:TimeAxisBreakCollection:TimeAxisBreak");
            a.item("ApplyCustomIndicatorsRef", "EventRef::applyCustomIndicators");
            FinancialChartDescriptionMetadata.e(a);
        }
        static d(a) {
            FinancialChartDescriptionMetadata.b(a);
            a.ad("FinancialChart", () => new FinancialChartDescription());
            a.ac("FinancialChart", FinancialChartDescriptionMetadata.a);
        }
    }
    FinancialChartDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialChartDescriptionMetadata, 'FinancialChartDescriptionMetadata');
    FinancialChartDescriptionMetadata.a = null;
    return FinancialChartDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/FinancialChartDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FinancialChartCustomIndicatorArgsDescriptionMetadata } from "./FinancialChartCustomIndicatorArgsDescriptionMetadata";
import { XYChartDescriptionMetadata } from "./XYChartDescriptionMetadata";
import { FinancialChartDescription } from "./FinancialChartDescription";
/**
 * @hidden
 */
export let FinancialChartDescriptionMetadata = /*@__PURE__*/ (() => {
    class FinancialChartDescriptionMetadata extends Base {
        static e(a) {
            a.item("TooltipTemplateRef", "(w:ToolTip)DataRef:String");
            a.item("_qualifiedName", "String:Infragistics.Controls.Charts.XamFinancialChart");
            a.item("Width", "(w:Width/DimensionTransform,xam:Width/DimensionTransform)String");
            a.item("Height", "(w:Height/DimensionTransform,xam:Height/DimensionTransform)String");
            a.item("Background", "(wf:BackColor/ColorTransform)Brush");
        }
        static b(a) {
            if (FinancialChartDescriptionMetadata.a == null) {
                FinancialChartDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                FinancialChartDescriptionMetadata.c(FinancialChartDescriptionMetadata.a);
            }
            if (a.k(FinancialChartDescriptionMetadata.a)) {
                return;
            }
            a.ac(FinancialChartDescriptionMetadata.a);
            FinancialChartCustomIndicatorArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            XYChartDescriptionMetadata.c(a);
            a.item("LeftMargin", "Number:double");
            a.item("IsHorizontalZoomEnabled", "Boolean");
            a.item("ToolbarHeight", "Number:double");
            a.item("YAxisIsLogarithmic", "Boolean");
            a.item("YAxisLogarithmBase", "Number:int");
            a.item("YAxisInterval", "Number:double");
            a.item("YAxisMinimumValue", "Number:double");
            a.item("YAxisMaximumValue", "Number:double");
            a.item("YAxisMinorInterval", "Number:double");
            a.item("VolumeType", "ExportedType:string:FinancialChartVolumeType");
            a.item("VolumeType@names", "None;Column;Line;Area");
            a.item("XAxisMode", "ExportedType:string:FinancialChartXAxisMode");
            a.item("XAxisMode@names", "Ordinal;Time");
            a.item("XAxisZoomMaximumCategoryRange", "Number:double");
            a.item("XAxisZoomToCategoryStart", "Number:double");
            a.item("XAxisZoomMaximumItemSpan", "Number:double");
            a.item("XAxisZoomToCategoryRange", "Number:double");
            a.item("XAxisZoomToItemSpan", "Number:double");
            a.item("YAxisMode", "ExportedType:string:FinancialChartYAxisMode");
            a.item("YAxisMode@names", "Numeric;PercentChange");
            a.item("IsToolbarVisible", "Boolean");
            a.item("ChartType", "ExportedType:string:FinancialChartType");
            a.item("ChartType@names", "Auto;Bar;Candle;Column;Line");
            a.item("YAxisLabelHorizontalAlignment", "ExportedType:string:HorizontalAlignment");
            a.item("YAxisLabelHorizontalAlignment@names", "Left;Center;Right;Stretch");
            a.item("IsWindowSyncedToVisibleRange", "Boolean");
            a.item("IndicatorTypes", "Collection:string:FinancialIndicatorTypeCollection:FinancialIndicatorType");
            a.item("IndicatorTypes@names", "AbsoluteVolumeOscillator;AccumulationDistribution;AverageDirectionalIndex;AverageTrueRange;BollingerBandWidth;ChaikinOscillator;ChaikinVolatility;CommodityChannelIndex;DetrendedPriceOscillator;EaseOfMovement;FastStochasticOscillator;ForceIndex;FullStochasticOscillator;MarketFacilitationIndex;MassIndex;MedianPrice;MoneyFlowIndex;MovingAverageConvergenceDivergence;NegativeVolumeIndex;OnBalanceVolume;PercentagePriceOscillator;PercentageVolumeOscillator;PositiveVolumeIndex;PriceVolumeTrend;RateOfChangeAndMomentum;RelativeStrengthIndex;SlowStochasticOscillator;StandardDeviation;StochRSI;TRIX;TypicalPrice;UltimateOscillator;WeightedClose;WilliamsPercentR");
            a.item("OverlayTypes", "Collection:string:FinancialOverlayTypeCollection:FinancialOverlayType");
            a.item("OverlayTypes@names", "BollingerBands;PriceChannel");
            a.item("YAxisAbbreviateLargeNumbers", "Boolean");
            a.item("Resolution", "Number:double");
            a.item("XAxisEnhancedIntervalPreferMoreCategoryLabels", "Boolean");
            a.item("YAxisEnhancedIntervalPreferMoreCategoryLabels", "Boolean");
            a.item("ZoomSliderType", "ExportedType:string:FinancialChartZoomSliderType");
            a.item("ZoomSliderType@names", "None;Auto;Bar;Candle;Column;Line;Area");
            a.item("NegativeBrushes", "BrushCollection:string");
            a.item("NegativeOutlines", "BrushCollection:string");
            a.item("OverlayBrushes", "BrushCollection:string");
            a.item("OverlayOutlines", "BrushCollection:string");
            a.item("VolumeOutlines", "BrushCollection:string");
            a.item("VolumeBrushes", "BrushCollection:string");
            a.item("IndicatorNegativeBrushes", "BrushCollection:string");
            a.item("IndicatorBrushes", "BrushCollection:string");
            a.item("VolumeThickness", "Number:double");
            a.item("OverlayThickness", "Number:double");
            a.item("OverlayMultiplier", "Number:double");
            a.item("IndicatorThickness", "Number:double");
            a.item("IndicatorDisplayTypes", "Collection:string:IndicatorDisplayTypeCollection:IndicatorDisplayType");
            a.item("IndicatorDisplayTypes@names", "Line;Area;Column");
            a.item("IndicatorPeriod", "Number:int");
            a.item("IndicatorMultiplier", "Number:double");
            a.item("IndicatorSmoothingPeriod", "Number:int");
            a.item("IndicatorShortPeriod", "Number:int");
            a.item("IndicatorLongPeriod", "Number:int");
            a.item("IndicatorSignalPeriod", "Number:int");
            a.item("RangeSelectorOptions", "Collection:string:FinancialChartRangeSelectorOptionCollection:FinancialChartRangeSelectorOption");
            a.item("RangeSelectorOptions@names", "OneMonth;ThreeMonths;SixMonths;YearToDate;OneYear;All");
            a.item("CustomIndicatorNames", "Collection:String:CustomIndicatorNameCollection:String");
            a.item("IsVerticalZoomEnabled", "Boolean");
            a.item("ZoomSliderXAxisMajorStroke", "Brush");
            a.item("ZoomSliderXAxisMajorStrokeThickness", "Number:double");
            a.item("IsLegendVisible", "Boolean");
            a.item("XAxisMinimumValue", "Date");
            a.item("XAxisMaximumValue", "Date");
            a.item("XAxisBreaks", "Collection:TimeAxisBreak:TimeAxisBreakCollection:TimeAxisBreak");
            a.item("ApplyCustomIndicatorsRef", "EventRef::applyCustomIndicators");
            FinancialChartDescriptionMetadata.e(a);
        }
        static d(a) {
            FinancialChartDescriptionMetadata.b(a);
            a.ae("FinancialChart", () => new FinancialChartDescription());
            a.ad("FinancialChart", FinancialChartDescriptionMetadata.a);
        }
    }
    FinancialChartDescriptionMetadata.$t = /*@__PURE__*/ markType(FinancialChartDescriptionMetadata, 'FinancialChartDescriptionMetadata');
    FinancialChartDescriptionMetadata.a = null;
    return FinancialChartDescriptionMetadata;
})();
